atomate.vasp.workflows.presets package — atomate 0.9.2 documentation

# atomate.vasp.workflows.presets package

## Submodules

## atomate.vasp.workflows.presets.core module

`atomate.vasp.workflows.presets.core.` `wf_bandstructure`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_bandstructure_hse`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_bandstructure_no_opt`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_bandstructure_plus_boltztrap`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_bandstructure_plus_hse`(structure, gap_only=True, c=None)

`atomate.vasp.workflows.presets.core.` `wf_bulk_modulus`(structure, c=None)

  Bulk modulus workflow from the given structure and config dict.

  Args:

    structure (Structure): input structure c (dict): workflow config dict

  Returns:

    Workflow

`atomate.vasp.workflows.presets.core.` `wf_dielectric_constant`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_dielectric_constant_no_opt`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_elastic_constant`(structure, c=None, order=2, sym_reduce=False)

`atomate.vasp.workflows.presets.core.` `wf_elastic_constant_minimal`(structure, c=None, order=2, sym_reduce=True)

`atomate.vasp.workflows.presets.core.` `wf_gibbs_free_energy`(structure, c=None)

  Gibbs free energy workflow from the given structure and config dict.

  Args:

    structure (Structure): input structure c (dict): workflow config dict

  Returns:

    Workflow

`atomate.vasp.workflows.presets.core.` `wf_nmr`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_nudged_elastic_band`(structures, parent, c=None)

  Nudged elastic band (NEB) workflow from the given structures and config dict.

  ‘is_optimized’ default False ‘neb_round’ default 1

  Notes:

    Length of Structure list and “is_optimized” are used to determine the workflow: 1 structure # The parent structure & two endpoint indexes provided; need relaxation.

    > # The parent structure & two endpoint indexes provided; no need to relax.

    2 structures # Two endpoints provided; need to relax two endpoints.

      # Two relaxed endpoints provided; no need to relax two endpoints.

    >=3 structures # All images including two endpoints are provided.

  Args:
    structures ([Structure]):

      1. The parent structure

      2. Two endpoint structures

      3. An initial NEB path that comprises both images and endpoints

    parent (Structure): parent structure used to get two endpoints. c (dict): workflow config dict, basic format:

    > {“fireworks”: [], “common_params”: {}, “additional_ep_params”: {},

    >   “additional_neb_params”: {}}. When the length of structures is 1, “site_indices” key must be included in c. Note that “fireworks” is a list corresponding to the order of execution.

  Returns:

    Workflow

`atomate.vasp.workflows.presets.core.` `wf_piezoelectric_constant`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_raman_spectra`(structure, c=None)

  Raman spectra workflow from the given structure and config dict

  Args:

    structure (Structure): input structure c (dict): workflow config dict

  Returns:

    Workflow

`atomate.vasp.workflows.presets.core.` `wf_static`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_structure_optimization`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_thermal_expansion`(structure, c=None)

  Thermal expansion coefficient workflow from the given structure and config dict.

  Args:

    structure (Structure): input structure c (dict): workflow config dict

  Returns:

    Workflow

## atomate.vasp.workflows.presets.scan module

`atomate.vasp.workflows.presets.scan.` `wf_scan_opt`(structure, c=None)

## Module contents